function varargout = trial(varargin)
% TRIAL M-file for trial.fig
%      TRIAL, by itself, creates a new TRIAL or raises the existing
%      singleton*.
%
%      H = TRIAL returns the handle to a new TRIAL or the handle to
%      the existing singleton*.
%
%      TRIAL('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in TRIAL.M with the given input arguments.
%
%      TRIAL('Property','Value',...) creates a new TRIAL or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before trial_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to trial_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help trial

% Last Modified by GUIDE v2.5 26-Jul-2009 17:32:27

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @trial_OpeningFcn, ...
                   'gui_OutputFcn',  @trial_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before trial is made visible.
function trial_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to trial (see VARARGIN)

% Choose default command line output for trial
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes trial wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = trial_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in csv.
function csv_Callback(hObject, eventdata, handles)
[header, dates, data] = csvreader;
[mu_hat sigma_hat] = estimBrownian(data(:,1))
showLogNormal(log(mu_hat),sigma_hat);
% hObject    handle to csv (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- Executes on button press in creader.
function creader_Callback(hObject, eventdata, handles)
[stock_vals,stock_time] = creader;
[mu_hat sigma_hat] = estimBrownian(stock_vals)
showLogNormal(log(mu_hat),sigma_hat);
% hObject    handle to creader (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


% --- If Enable == 'on', executes on mouse press in 5 pixel border.
% --- Otherwise, executes on mouse press in 5 pixel border or over csv.
function csv_ButtonDownFcn(hObject, eventdata, handles)
% hObject    handle to csv (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

